@@ -21,7 +21,8 @@
 
 from __future__ import print_function
 import os
-from opsramp.base import ApiWrapper, Helpers
+
+from opsramp.api import ORapi
 
 '''
 POST install/{intgld} e.g. CUSTOM
@@ -43,7 +44,7 @@ GET available/{intgld}/mappingAttr/{entityType}
 '''
 
 
-class Integrations(ApiWrapper):
+class Integrations(ORapi):
     def __init__(self, parent):
         super(Integrations, self).__init__(parent.api, 'integrations')
 
@@ -64,18 +65,12 @@ class Integrations(ApiWrapper):
         return self.instances()
 
 
-class Types(ApiWrapper):
+class Types(ORapi):
     def __init__(self, parent):
         super(Types, self).__init__(parent.api, 'available')
 
-    def search(self, pattern=''):
-        suffix = 'search'
-        if pattern:
-            suffix += '?' + pattern
-        return self.api.get(suffix)
 
-
-class Instances(ApiWrapper):
+class Instances(ORapi):
     def __init__(self, parent):
         super(Instances, self).__init__(parent.api, 'installed')
         # The OpsRamp "create instance" API endpoint is in an
@@ -83,12 +78,6 @@ class Instances(ApiWrapper):
         self.creator_api = parent.api.clone()
         self.creator_api.chroot('install')
 
-    def search(self, pattern=''):
-        suffix = 'search'
-        if pattern:
-            suffix += '?' + pattern
-        return self.api.get(suffix)
-
     def get_kubernetes_configuration(self, uuid):
         return self.api.get('%s/configFile/kubernetes' % uuid)
 
@@ -119,6 +108,7 @@ class Instances(ApiWrapper):
         return self.api.post('%s/disable' % uuid)
 
     def notifier(self, uuid, definition):
+        # Create or update installed integration base notifier
         return self.api.post('%s/notifier' % uuid, json=definition)
 
     # A helper function that extracts the authentication types from typical
@@ -161,7 +151,7 @@ class Instances(ApiWrapper):
             'displayName': display_name,
         }
         if logo_fname:
-            payload = Helpers.b64encode_payload(logo_fname)
+            payload = ORapi.b64encode_payload(logo_fname)
             retval['logo'] = {
                 'name': os.path.basename(logo_fname),
                 'file': payload
